@@ -7,7 +7,7 @@ test_that("default_style", {
   expect_true(
     all(
       names(def) %in%
-      c("reserved", "number", "null", "operator", "call", "string", "comment")
+      c("reserved", "number", "null", "operator", "call", "string", "comment", "bracket")
     )
   )
 })
